Learn R Programming

robfilter (version 4.1.3)

sizecorrection: Bias correction factors for the robust scale estimators MAD, Sn, Qn, and LSH

Description

This matrix contains correction factors for the MAD, Sn, Qn, and LSH scale estimators to achieve unbiasedness under Gaussian noise.

Usage

sizecorrection

Arguments

Format

A (31x4)-matrix containing correction factors for the MAD, Sn, Qn, and LSH scale estimators.